@@ -41,7 +41,7 @@ class tax_credits_applicable_income(Variable):
             "social_security_income",
             "miscellaneous_income",
         ]
-        bi = parameters(period).contrib.ubi_center.basic_income
+        bi = parameters(period).gov.contrib.ubi_center.basic_income
         if bi.interactions.include_in_means_tests:
             STEP_2_COMPONENTS.append("basic_income")
         income += aggr(benunit, period, STEP_2_COMPONENTS)
